@@ -42,7 +42,8 @@ class Pygame:
         self.movementAmount = 1
         self.stayInBounds = None
 
-        self.background = pygame.image.load(self.backgroundImage)
+        # self.background = pygame.image.load(self.backgroundImage)
+        self.background = self.backgroundImage
         self.background = pygame.transform.scale(self.background, size)
         self.mixer.init()
         if backgroundSound:
